#ifndef SQLNCLI_H
#define SQLNCLI_H

/*
 * extra SQLServer values
 */

#define SQL_COPT_SS_BASE						1200

#define SQL_COPT_SS_PERF_DATA_LOG				(SQL_COPT_SS_BASE+12)
#define SQL_COPT_SS_MARS_ENABLED				(SQL_COPT_SS_BASE+24)

#define SQL_MARS_ENABLED_NO						0L
#define SQL_MARS_ENABLED_YES					1L

#define SQL_TXN_SS_SNAPSHOT						0x00000020L

#define SQL_COPT_SS_PRESERVE_CURSORS            (SQL_COPT_SS_BASE+4) /* Preserve server cursors after SQLTransact */
#define SQL_COPT_SS_INTEGRATED_SECURITY         (SQL_COPT_SS_BASE+3) /* Force integrated security on login */

#define SQL_COPT_SS_TXN_ISOLATION				(SQL_COPT_SS_BASE+27)
#define SQL_COPT_SS_FAILOVER_PARTNER			(SQL_COPT_SS_BASE+25)
#define SQL_COPT_SS_TRUST_SERVER_CERTIFICATE	(SQL_COPT_SS_BASE+28)
#define SQL_COPT_SS_ENCRYPT						(SQL_COPT_SS_BASE+23)

#define SQL_COPT_SS_SERVER_SPN                  (SQL_COPT_SS_BASE+29) /* Server SPN */
#define SQL_COPT_SS_INTEGRATED_AUTHENTICATION_METHOD    (SQL_COPT_SS_BASE+31) /* The integrated authentication method used for the connection*/
#define SQL_COPT_SS_MUTUALLY_AUTHENTICATED      (SQL_COPT_SS_BASE+32) /* Used to decide if the connection is mutually authenticated */

#define SQL_COPT_SS_BASE_EX                     1240

#define SQL_COPT_SS_CONNECTION_DEAD				(SQL_COPT_SS_BASE_EX+4)

#define SQL_PRESERVE_CURSORS                    SQL_COPT_SS_PRESERVE_CURSORS

#define SQL_COPT_SS_TXN_ISOLATION				(SQL_COPT_SS_BASE+27)

#define SQL_SOPT_SS_BASE                        1225

#define SQL_SOPT_SS_CURSOR_OPTIONS              (SQL_SOPT_SS_BASE+5) /* Server cursor options */
#define SQL_SOPT_SS_DEFER_PREPARE               (SQL_SOPT_SS_BASE+7) /* Defer prepare until necessary */

/* Defines for use with SQL_COPT_SS_INTEGRATED_SECURITY - Pre-Connect Option only */
#define SQL_IS_OFF                          0L           /*  Integrated security isn't used */
#define SQL_IS_ON                           1L           /*  Integrated security is used */
#define SQL_IS_DEFAULT                      SQL_IS_OFF

/* Defines for use with SQL_COPT_SS_PRESERVE_CURSORS */
#define SQL_PC_OFF                          0L           /*  Cursors are closed on SQLTransact */
#define SQL_PC_ON                           1L           /*  Cursors remain open on SQLTransact */
#define SQL_PC_DEFAULT                      SQL_PC_OFF

/* SQL_SOPT_SS_DEFER_PREPARE */
#define SQL_DP_OFF                          0L
#define SQL_DP_ON                           1L

/* Defines for use with SQL_SOPT_SS_CURSOR_OPTIONS */
#define SQL_CO_OFF                          0L           /*  Clear all cursor options */
#define SQL_CO_FFO                          1L           /*  Fast-forward cursor will be used */
#define SQL_CO_AF                           2L           /*  Autofetch on cursor open */
#define SQL_CO_FFO_AF                       (SQL_CO_FFO|SQL_CO_AF)  /*  Fast-forward cursor with autofetch */
#define SQL_CO_FIREHOSE_AF                  4L           /*  Auto fetch on fire-hose cursors */
#define SQL_CO_DEFAULT                      SQL_CO_OFF

/* 
 * SQL_SS_LENGTH_UNLIMITED is used to describe the max length of
 * VARCHAR(max), VARBINARY(max), NVARCHAR(max), and XML columns
 */
#define SQL_SS_LENGTH_UNLIMITED             0

/*
 * SQL Server 2008 new datatypes
 */

#define SQL_SS_VARIANT                      (-150)
#define SQL_SS_UDT                          (-151)
#define SQL_SS_XML                          (-152)
#define SQL_SS_TABLE                        (-153)
#define SQL_SS_TIME2                        (-154)
#define SQL_SS_TIMESTAMPOFFSET              (-155)

/* SQLGetDiagField driver specific defines. */
/* Microsoft has -1150 thru -1199 reserved for Microsoft SQL Server Native Client driver usage. */
#define SQL_DIAG_SS_BASE                    (-1150)
#define SQL_DIAG_SS_MSGSTATE                (SQL_DIAG_SS_BASE)
#define SQL_DIAG_SS_SEVERITY                (SQL_DIAG_SS_BASE-1)
#define SQL_DIAG_SS_SRVNAME                 (SQL_DIAG_SS_BASE-2)
#define SQL_DIAG_SS_PROCNAME                (SQL_DIAG_SS_BASE-3)
#define SQL_DIAG_SS_LINE                    (SQL_DIAG_SS_BASE-4)

/* Severity codes for SQL_DIAG_SS_SEVERITY */
#define EX_ANY          0
#define EX_INFO         10
#define EX_MAXISEVERITY EX_INFO
#define EX_MISSING      11
#define EX_TYPE         12
#define EX_DEADLOCK     13
#define EX_PERMIT       14
#define EX_SYNTAX       15
#define EX_USER         16
#define EX_RESOURCE     17
#define EX_INTOK        18
#define MAXUSEVERITY    EX_INTOK
#define EX_LIMIT        19
#define EX_CMDFATAL     20
#define MINFATALERR     EX_CMDFATAL
#define EX_DBFATAL      21
#define EX_TABCORRUPT   22
#define EX_DBCORRUPT    23
#define EX_HARDWARE     24
#define EX_CONTROL      25


/* New Date Time Structures */
/* New Structure for TIME2 */
/* EASYSOFT ADDITION ============================================================================== */
/* There is a bit of a gotcha here, the normal packing would make this 12 bytes in length           */
/* but MS set the allignment to 2 bytes, so it becomes 10 bytes. If we forced this to 2 byte        */
/* in the driver, then there would need to be a platform specific packing pragma, so for the        */
/* moment, allow this to end up being size 12, this may change before the end of the beta depending */
/* on feedback we get                                                                               */
/* END EASYSOFT ADDITION ========================================================================== */
typedef struct tagSS_TIME2_STRUCT
    {
    SQLUSMALLINT hour;
    SQLUSMALLINT minute;
    SQLUSMALLINT second;
    SQLUINTEGER fraction;
    } 	SQL_SS_TIME2_STRUCT;

/* New Structure for TIMESTAMPOFFSET */
typedef struct tagSS_TIMESTAMPOFFSET_STRUCT
    {
    SQLSMALLINT year;
    SQLUSMALLINT month;
    SQLUSMALLINT day;
    SQLUSMALLINT hour;
    SQLUSMALLINT minute;
    SQLUSMALLINT second;
    SQLUINTEGER fraction;
    SQLSMALLINT timezone_hour;
    SQLSMALLINT timezone_minute;
    } 	SQL_SS_TIMESTAMPOFFSET_STRUCT;

#endif
